@@ -60,7 +60,7 @@ use strict;
 use warnings;
 
 package USB::TMC;
-$USB::TMC::VERSION = '0.006';
+$USB::TMC::VERSION = '0.007';
 use USB::LibUSB;
 use Moose;
 use MooseX::Params::Validate 'validated_list';
@@ -749,6 +749,15 @@ CLEAR_FEATURE request to clear the Bulk-OUT Halt.
 =cut
 
 sub clear {
+    my $self = shift;
+    $self->clear_without_output_clear(@_);
+    my ($timeout) = validated_list( \@_, _timeout_arg() );
+
+    # Required by USB-TMC standard?
+    $self->clear_feature_endpoint_out( timeout => $timeout );
+}
+
+sub clear_without_output_clear {
     my $self = shift;
     my ($timeout) = validated_list( \@_, _timeout_arg() );
     my $initiate_status = $self->initiate_clear( timeout => $timeout );
@@ -786,9 +795,9 @@ sub clear {
             croak "CHECK_CLEAR_STATUS failed with status $status";
         }
     }
-    $self->clear_feature_endpoint_out( timeout => $timeout );
 }
 
+
 sub initiate_clear {
     my $self = shift;
     my ($timeout) = validated_list( \@_, _timeout_arg() );
